/*******************************************************************************
 *  Imixs IX Workflow Technology
 *  Copyright (C) 2001, 2008 Imixs Software Solutions GmbH,  
 *  http://www.imixs.com
 *  
 *  This program is free software; you can redistribute it and/or 
 *  modify it under the terms of the GNU General Public License 
 *  as published by the Free Software Foundation; either version 2 
 *  of the License, or (at your option) any later version.
 *  
 *  This program is distributed in the hope that it will be useful, 
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of 
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 *  General Public License for more details.
 *  
 *  You can receive a copy of the GNU General Public
 *  License at http://www.gnu.org/licenses/gpl.html
 *  
 *  Contributors:  
 *  	Imixs Software Solutions GmbH - initial API and implementation
 *  	Ralph Soika
 *******************************************************************************/
package org.imixs.workflow.jee.jpa;

import javax.persistence.*;

/**
 * A TextItem is a subdata item of the data object class WorkItem. These subdata
 * types are used to extract single attributes of an ItemCollection from the
 * data Attribute of a WorkItem outside to seperate entity ejbs. As both - the
 * WorkItem and the SubDataItem are Entity EJBs this facilitate the possibility
 * of a object-relational data mapping into different table.
 * 
 * @see org.imixs.workflow.jee.jpa.Entity
 * @see org.imixs.workflow.jee.ejb.EntityPersistenceManagerImplementation
 * @author  Ralph Soika
 * @version 1.0
 * 
 */
@javax.persistence.Entity
public class TextItem implements java.io.Serializable {

	/**
	 *  default serial id
	 */
	private static final long serialVersionUID = 1L;

	@SuppressWarnings("unused")
	@Id
	@GeneratedValue
	private String universalItemId;

	public String itemValue;

	public String itemName;

	@SuppressWarnings("unused")
	private TextItem() {
	}

	public TextItem(String name, String value) {
		itemValue = value;
		itemName = name;
	}

	
	
	
	@Override
	public int hashCode() {
		return ((itemValue+itemName).hashCode());
		//return super.hashCode();
	}

	@Override
	public boolean equals(Object obj) {
		if (obj == null)
			return false;
		if (!(obj instanceof TextItem))
			return false;

		TextItem aItem = (TextItem) obj;
		return (aItem.itemName.equals(itemName) && aItem.itemValue
				.equals(itemValue));

	}

}
